Struct DocumentReferenceBatch

pub struct DocumentReferenceBatch {
    pub documents: Vec<DocumentReference>,
}
Represents a batch (collection in the form of a Vec) of DocumentReferences.

This struct is particularly useful for scanning, as it allows one function call to take many different document references. It also enables ‘processing groups’—i.e. groups of documents that will always be processed together in the same thread.

Fields

documents: Vec<DocumentReference>

Contains the DocumentReferences